function C = sp1(A,B)

% SP1     (Left) Semi-Tensor Product of Matrices by its definition
%
%   SP1(A,B) is to calculate the left semi-tensor product of two arbitrary matrices A and B.

if ~(isa(A,'sym') || isa(A,'double'))
    A = double(A);
end
if ~(isa(B,'sym') || isa(B,'double'))
    B = double(B);
end

if (ndims(A) > 2) || (ndims(B) > 2)
    error('Input arguments must be 2-D.');
end

n = size(A,2);
p = size(B,1);
if n == p
    C = A * B;
elseif mod(n,p) == 0
    C = leftsp(A,B);
elseif mod(p,n) == 0
    C = (leftsp(B.',A.')).';
else
% for other cases, it will use the kron function to expand them and make their dimensions match
    z = lcm(n,p);
    C = kron(A,eye(z/n))*kron(B,eye(z/p));
%   error('The input arguments do not meet the multiple dimension matching condition.');
end

function C = leftsp(A,B)
[m,n] = size(A);
[p,q] = size(B);
k = n/p;
C = zeros(m,k*q);
if isa(A,'sym') | isa(B,'sym')
    C = sym(C);
end
for i = 1:m
    for j = 1:q
        C(i,((j-1)*k+1):(j*k)) = (reshape(A(i,:),k,p)*B(:,j)).';
    end
end